@@ -1,4 +1,4 @@
-estim_ncpMCA <- function(don,ncp.min=0,ncp.max=5,method.cv="gcv",nbsim=100,pNA=0.05,threshold=1e-4){
+estim_ncpMCA <- function(don,ncp.min=0,ncp.max=5,method=c("Regularized","EM"),method.cv=c("gcv","loo","Kfold"),nbsim=100,pNA=0.05,threshold=1e-4){
 
 #### Debut tab.disjonctif.NA
 tab.disjonctif.NA<-function (tab) {
@@ -30,6 +30,9 @@ tab.disjonctif.NA<-function (tab) {
 
 ########## Debut programme principal
 
+  method <- match.arg(method,c("Regularized","regularized","EM","em"),several.ok=T)[1]
+method.cv <- match.arg(method.cv,c("gcv","loo","Kfold","GCV","kfold","LOO"),several.ok=T)[1]
+method <- tolower(method)
 method.cv <- tolower(method.cv)
 auxi = NULL
 for (j in 1:ncol(don)) if (is.numeric(don[,j])) auxi = c(auxi,colnames(don)[j])
@@ -41,12 +44,12 @@ p=ncol(don)
 n=nrow(don)
 crit <- NULL
 tabX <- tab.disjonctif.NA(don)
-if (is.null(ncp.max)) ncp.max <- ncol(tabX)-2
-ncp.max <- min(nrow(tabX)-2,ncol(tabX)-1,ncp.max)
+if (is.null(ncp.max)) ncp.max <- ncol(tabX)-ncol(don)-1
+ncp.max <- min(nrow(tabX)-2,ncol(tabX)-ncol(don)-1,ncp.max)
 pquali <- ncol(tabX)
 if (ncp.min == 0) crit = mean((tabX - rep(colMeans(tabX, na.rm = TRUE), each = nrow(tabX)))^2, na.rm = TRUE)
     for (q in max(ncp.min,1):ncp.max) {
-        Z <- imputeMCA(don,ncp=q)$tab.disj
+        Z <- imputeMCA(don,ncp=q,method=method)$tab.disj
         Z <- scale(Z)*sqrt(nrow(Z)/(nrow(Z)-1))/sqrt(ncol(Z))
         ponder <- 1-apply(Z/nrow(Z), 2, sum)
         Z <- sweep(Z,2,sqrt(ponder),FUN="*")
@@ -61,22 +64,41 @@ if (ncp.min == 0) crit = mean((tabX - rep(colMeans(tabX, na.rm = TRUE), each = n
   return(list(ncp = as.integer(ncp+ncp.min-1),criterion=crit))
 }
 
-if (method.cv=="cv"){
+if (method.cv=="kfold"){
 res = matrix(NA,ncp.max-ncp.min+1,nbsim)
 
 for (sim in 1:nbsim){
  donNA <- as.matrix(don)
  donNA[sample(1:(nrow(donNA)*ncol(donNA)),round(pNA*nrow(donNA)*ncol(donNA),0))] <- NA
  for (i in 1:ncol(don)) donNA[,i]=as.factor(as.character(donNA[,i]))
-
  for (nbaxes in ncp.min:ncp.max){
-  tab.disj.comp <- imputeMCA(as.data.frame(donNA),ncp=nbaxes,threshold=threshold)$tab.disj
-  res[nbaxes-ncp.min+1,sim] <- sum((tab.disj.comp-vrai.tab)^2,na.rm=TRUE)
+  tab.disj.comp <- imputeMCA(as.data.frame(donNA),ncp=nbaxes,method=method,threshold=threshold)$tab.disj
+  if (sum(!(which(is.na(donNA))%in%which(is.na(don))))!=0) res[nbaxes-ncp.min+1,sim] <- sum((tab.disj.comp-vrai.tab)^2,na.rm=TRUE)/sum(!(which(is.na(donNA))%in%which(is.na(don))))
  }
 }
-crit=apply(res,1,mean)
+crit=apply(res,1,mean,na.rm=TRUE)
  names(crit) <- c(ncp.min:ncp.max)
 result = list(ncp = as.integer(which.min(crit)+ncp.min-1),criterion=crit)
 return(result)
 }
+
+if (method.cv=="loo"){
+crit <- NULL
+tab.disj.hat <- vrai.tab
+col.in.indicator <- c(0,sapply(don,nlevels))
+ for (nbaxes in ncp.min:ncp.max){
+   for (i in 1:nrow(don)){
+    for (j in 1:ncol(don)){
+     if (!is.na(don[i,j])){
+       donNA <- as.matrix(don)
+       donNA[i,j] <- NA
+       for (k in 1:ncol(donNA)) donNA[,k]=as.factor(as.character(donNA[,k]))
+       tab.disj.hat[i,(cumsum(col.in.indicator)[j]+1):(cumsum(col.in.indicator)[j+1])] <- imputeMCA(as.data.frame(donNA),ncp=nbaxes,method=method,threshold=threshold)$tab.disj[i,(cumsum(col.in.indicator)[j]+1):(cumsum(col.in.indicator)[j+1])]
+ }
+}}
+crit <- c(crit,mean((tab.disj.hat-vrai.tab)^2,na.rm=TRUE))
 }
+names(crit) <- c(ncp.min:ncp.max)
+return(list(ncp = as.integer(which.min(crit)+ncp.min-1),criterion=crit))
+}
+}
\ No newline at end of file
